@@ -19,7 +19,6 @@
 
 #include <cmath>
 #include <vector>
-#include <string>
 #include <numeric>
 #include <algorithm>
 
@@ -223,7 +222,7 @@ int bootstrap_alpha_nonparametric(
     const std::vector<double> &data,
     const int nC,
     const int nU,
-    const std::string &metric,
+    const int metric,
     const int bootstraps,
     const unsigned long seed[6],
     const int n_threads,
